==> underscore-transducer-0.0.1.tgz: package/tests.js <==
var _r = require('./underscore.transducer')._r;
var _ = require('underscore');
_.mixin({r: _r});

function isEven(x){
  return x % 2 !== 1;
}

function inc(x){
  return x+1;
}

function printIt(result, input){
  console.log(input+' ['+result+']');
}

var printEach = _r.tap(printIt);
var trans, result;

//result = _.r.into([3], [1,2,3,4]);

//result = _.r.into([], _.r.filter(isEven), [1,2,3,4]);
//result = _.r.into([3], _.r.reject(isEven), [1,2,3,4]);
//result = _.r.into([3], _.r.map(inc), [1,2,3,4]);
//result = _.r.into([], _.compose(_.r.filter(isEven), _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([3], _.compose(_.r.map(inc), printEach, _.r.filter(isEven), printEach, _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([3], _.compose(_.r.map(inc), printEach, _.r.filter(isEven), printEach, _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([], _.r.invoke('sort'), [[5, 1, 7], [3, 2, 1]]);

//trans = _.compose(_.r.filter(isEven), _.r.map(inc))
//trans = _.r.chain().filter(isEven).map(inc).value();
//trans = _.r.chain().filter(isEven).map(inc);
//trans = _.r(trans).map(inc);
//trans = trans.map(inc);
//result = _.r.into([], trans, [1,2,3,4, 5]);

/*
trans = _.r.chain()
  .filter(function(num) { return num % 2 == 0; })
  .tap(printIt)
  .map(function(num) { return num * num })
  .value();
result = _.r.into([], trans, [1,2,3,200]);
*/

var stooges = [{name: 'moe', age: 40}, {name: 'larry', age: 50}, {name: 'curly', age: 40}];
//result = _.r.into([], _.r.pluck('name'), stooges);


//result = _.r.into([], _.r.where({age: 40}), stooges);
//result = _.r.into([], _.r.findWhere({age: 40}), stooges);

//result = _.r.into([], _.r.where({age: 40}), stooges);
//result = _.r.into([], _.r.compact(), [0, 1, false, 2, '', 3]);


// result = _.r.into([], _.r.every(isEven), [0, 2, 8, 4, 8]);
//result = _.r.into([], _.r.every(isEven), [0, 2, 7, 8, 9]);

//result = _.r.into([], _.r.some(isEven), [1, 3, 7, 8, 9]);
//result = _.r.into([], _.r.some(isEven), [1, 3, 7, 11, 9]);

//result = _.r.into([], _.r.contains(3), [1, 3, 7, 11, 9]);
//result = _.r.into([], _.r.contains(3), [1, 10, 7, 11, 9]);

//result = _.r.into([], _.r.find(isEven), [7, 8, 7, 11, 12]);
//result = _.r.into([], _.r.find(isEven), [1, 9, 13, 11, 9]);
//result = _.r.into([], _.r.first(3), [1, 9, 13, 11, 9]);
//result = _.r.into([], _.r.max(), [1, 9, 13, 11, 9]);
result = _.r.into([], _.r.min(), [11, 9, 13, 11, 9]);
console.log(result);

==> underscore-transducer-0.0.2.tgz: package/tests.js <==
var _r = require('./underscore.transducer')._r;
var _ = require('underscore');
_.mixin({r: _r});

function isEven(x){
  return +x == x && (x % 2 === 0);
}

function inc(x){
  return x+1;
}

function printIt(result, input){
  console.log(input+' ['+result+']');
}

function logEach(input, i, result){
  console.log(input+' ['+i+': '+result+']');
}

var printEach = _r.tap(printIt);
var trans, result;

//result = _.r.into([3], [1,2,3,4]);

//result = _.r.into([], _.r.filter(isEven), [1,2,3,4]);
//result = _.r.into([3], _.r.reject(isEven), [1,2,3,4]);
//result = _.r.into([3], _.r.map(inc), [1,2,3,4]);
//result = _.r.into([], _.compose(_.r.filter(isEven), _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([3], _.compose(_.r.map(inc), printEach, _.r.filter(isEven), printEach, _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([3], _.compose(_.r.map(inc), printEach, _.r.filter(isEven), printEach, _.r.map(inc)), [1,2,3,4]);
//result = _.r.into([], _.r.invoke('sort'), [[5, 1, 7], [3, 2, 1]]);

//trans = _.compose(_.r.filter(isEven), _.r.map(inc))
//trans = _.r.chain().filter(isEven).map(inc).value();
//trans = _.r.chain().filter(isEven).map(inc);
//trans = _.r(trans).map(inc);
//trans = trans.map(inc);
//result = _.r.into([], trans, [1,2,3,4, 5]);
//result = _.r.into([], trans, [1,2,3,4, 5]);
//result = _.r.chain().filter(isEven).map(inc).transduce([1, 2, 3, 4]);
//result = _.r.chain().filter(isEven).map(inc).transduce([1, 2, 3, 4]);
//result = _.r.chain().filter(isEven).map(inc).into([1,2], [1, 2, 3, 4]);

/*
trans = _.r.chain()
  .filter(function(num) { return num % 2 == 0; })
  .tap(printIt)
  .map(function(num) { return num * num })
  .value();
result = _.r.into([], trans, [1,2,3,200]);
*/

var stooges = [{name: 'moe', age: 40}, {name: 'larry', age: 50}, {name: 'curly', age: 40}];
//result = _.r.into([], _.r.pluck('name'), stooges);


//result = _.r.into([], _.r.where({age: 40}), stooges);
//result = _.r.into([], _.r.findWhere({age: 40}), stooges);

//result = _.r.into([], _.r.where({age: 40}), stooges);
//result = _.r.into([], _.r.compact(), [0, 1, false, 2, '', 3]);


// result = _.r.into([], _.r.every(isEven), [0, 2, 8, 4, 8]);
//result = _.r.into([], _.r.every(isEven), [0, 2, 7, 8, 9]);

//result = _.r.into([], _.r.some(isEven), [1, 3, 7, 8, 9]);
//result = _.r.into([], _.r.some(isEven), [1, 3, 7, 11, 9]);

//result = _.r.into([], _.r.contains(3), [1, 3, 7, 11, 9]);
//result = _.r.into([], _.r.contains(3), [1, 10, 7, 11, 9]);

//result = _.r.into([], _.r.find(isEven), [7, 8, 7, 11, 12]);
//result = _.r.into([], _.r.find(isEven), [1, 9, 13, 11, 9]);
//result = _.r.into([], _.r.first(3), [1, 9, 13, 11, 9]);
//result = _.r.into([], _.r.max(), [1, 9, 13, 11, 9]);
//result = _.r.into([], _.r.min(), [11, 9, 13, 11, 9]);
//result = _.r.into([], _.r.filter(isEven), [1,2,3,4]);
//
//result = _.r.transduce(_.r.filter(isEven), [1,2,3,4]);
//result = _.r.chain().filter(isEven).transduce([1,2,3,4]);

//trans = _.r.chain().filter(isEven).map(inc).value();
//result = _.r.into([], trans, [1,2,3,4, 5]);
//result = _.r.chain().filter(isEven).map(inc).transduce([1,2,3,4,5]);
//result = _.r.chain().invoke('sort').transduce([[5, 1, 7], [3, 2, 1]]);
/*
trans = _.r.chain()
  .filter(function(num) { return num % 2 == 0; })
  .tap(printIt)
  .map(function(num) { return num * num })
  
result = trans.transduce([1,2,3,200]);
console.log(result);

result = trans.transduce([2,2,5,200]);
*/

function* genNums(){
  yield 1;
  yield 2;
  yield 3;
  yield 4;
  yield 4;
  yield 7;
  yield 4;
}

result = _.r.into([], _.r.first(3), genNums());

function fib(){
  var x=1, y=1;
  return function(){
    var prev = x;
    x = y;
    y += prev;
    return prev;
  }
}

//result = _.r.into([], _.r.first(7), _r.generate(fib()));
//result = _.r.chain().first(7).transduce(_r.generate(fib()));
result = _.r.chain().first(7).generate(fib());
//result = _.r.transduce(_r.first(7), _r.generate(fib()));
//console.log(result);

var cb = _r.chain().filter(isEven).map(inc).each(logEach).asCallback();
/*console.log(cb(1));
console.log(cb(2));
console.log(cb(3));
console.log(cb(4));
console.log(cb(4));
console.log(cb(5));
console.log(cb(5));*/
_.chain(_.range(1, 10)).each(function(i){
  cb(i);
});
